# MigrationPartialExportResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**package_id** | **str** |  | [optional] 
**space_id** | **str** |  | [optional] 
**package_version** | **str** |  | [optional] 
**password** | **str** |  | [optional] 
**projects** | **list[str]** |  | [optional] 
**ignore_certificates** | **bool** |  | [optional] 
**ignore_machines** | **bool** |  | [optional] 
**ignore_deployments** | **bool** |  | [optional] 
**ignore_tenants** | **bool** |  | [optional] 
**include_task_logs** | **bool** |  | [optional] 
**encrypt_package** | **bool** |  | [optional] 
**destination_api_key** | **str** |  | [optional] 
**destination_package_feed** | **str** |  | [optional] 
**destination_package_feed_space_id** | **str** |  | [optional] 
**success_callback_uri** | **str** |  | [optional] 
**failure_callback_uri** | **str** |  | [optional] 
**task_id** | **str** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


